autowisp.processing_steps.epd module — AutoWISP documentation

# autowisp.processing_steps.epd module

## Class Inheritance Diagram

Apply EPD correction to lightcurves.

autowisp.processing_steps.epd.epd(lc_collection, start_status, configuration, mark_progress)

  Perform EPD on (a subset of the points in) the given lightucurves.

autowisp.processing_steps.epd.main()

  Run the step from the command line.

autowisp.processing_steps.epd.parse_command_line(*args)

  Parse the commandline optinos to a dictionary.